package com.example.daniel_siamobile

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.example.daniel_siamobile.ui.theme.SIAMobileTheme
import android.content.Intent
import androidx.compose.ui.platform.LocalContext

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            SIAMobileTheme {
                AppNavigator()
            }
        }
    }
}

@Composable
fun AppNavigator() {
    var currentScreen by remember { mutableStateOf("MainMenu") }

    when (currentScreen) {
        "MainMenu" -> MainMenuScreen(
            onMenuClick = { selectedMenu ->
                when (selectedMenu) {
                    "About" -> currentScreen = "AboutScreen"
                    "Pengaturan" -> currentScreen = "SettingsScreen"
                    "Bantuan" -> currentScreen = "HelpScreen"
                    "Jadwal Kuliah" -> currentScreen = "JadwalKuliahScreen"
                }
            }
        )
        "AboutScreen" -> AboutScreen(onBackClick = { currentScreen = "MainMenu" })
        "SettingsScreen" -> SettingsScreen(onBackClick = { currentScreen = "MainMenu" })
        "HelpScreen" -> HelpScreen(onBackClick = { currentScreen = "MainMenu" })
        "JadwalKuliahScreen" -> JadwalKuliahScreen(onBackClick = { currentScreen = "MainMenu" })
    }
}

@Composable
fun MainMenuScreen(onMenuClick: (String) -> Unit, modifier: Modifier = Modifier) {
    val context = LocalContext.current

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column(verticalArrangement = Arrangement.spacedBy(12.dp)) {
            Text(
                text = "Selamat Datang di Aplikasi Akademik (DanielSIA)",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Text(
                text = "Pilih menu di bawah untuk melanjutkan:",
                style = MaterialTheme.typography.bodyMedium
            )
            Spacer(modifier = Modifier.height(8.dp))

            val menuItems = listOf(
                "Kartu Hasil Studi",
                "Jadwal Kuliah",
                "Pengaturan",
                "Bantuan",
                "About"
            )

            menuItems.forEach { menu ->
                MenuCard(menuTitle = menu) {
                    when (menu) {
                        "Kartu Hasil Studi" -> {
                            context.startActivity(Intent(context, KHSActivity::class.java))
                        }
                        else -> {
                            onMenuClick(menu)
                        }
                    }
                }
            }
        }

        Footer(version = "1.0.0", copyright = "\u00A9 2025")
    }
}

@Composable
fun MenuCard(menuTitle: String, onClick: () -> Unit) {
    Card(
        shape = RoundedCornerShape(12.dp),
        modifier = Modifier
            .fillMaxWidth()
            .clickable { onClick() },
        elevation = CardDefaults.cardElevation(defaultElevation = 4.dp)
    ) {
        Box(
            modifier = Modifier
                .padding(16.dp)
                .fillMaxWidth(),
            contentAlignment = Alignment.CenterStart
        ) {
            Text(
                text = menuTitle,
                style = MaterialTheme.typography.bodyLarge,
                fontWeight = FontWeight.Medium
            )
        }
    }
}

@Composable
fun AboutScreen(onBackClick: () -> Unit) {
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column(
            modifier = Modifier.fillMaxWidth(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = "Tentang Aplikasi",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = "Aplikasi Akademik ini dibuat untuk membantu mahasiswa mengakses informasi akademik seperti jadwal, presensi, dan berita kampus. Dikembangkan oleh Fasilkom Ubharajaya.",
                style = MaterialTheme.typography.bodyMedium,
                textAlign = TextAlign.Center
            )
            Spacer(modifier = Modifier.height(16.dp))
            Text(
                text = "Versi 1.0.0",
                style = MaterialTheme.typography.bodySmall,
                fontWeight = FontWeight.Light,
                textAlign = TextAlign.Center
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = "\u00A9 2025 Fasilkom Ubharajaya",
                style = MaterialTheme.typography.bodySmall,
                fontWeight = FontWeight.Light,
                textAlign = TextAlign.Center
            )
        }

        Button(
            onClick = onBackClick,
            modifier = Modifier.align(Alignment.CenterHorizontally)
        ) {
            Text(text = "Kembali ke Menu Utama")
        }
    }
}

@Composable
fun SettingsScreen(onBackClick: () -> Unit) {
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column(
            modifier = Modifier.fillMaxWidth(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = "Pengaturan",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = "Atur preferensi aplikasi Anda di sini.",
                style = MaterialTheme.typography.bodyMedium,
                textAlign = TextAlign.Center
            )
        }

        Button(
            onClick = onBackClick,
            modifier = Modifier.align(Alignment.CenterHorizontally)
        ) {
            Text(text = "Kembali ke Menu Utama")
        }
    }
}

@Composable
fun HelpScreen(onBackClick: () -> Unit) {
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column(
            modifier = Modifier.fillMaxWidth(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = "Bantuan",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = "Jika Anda membutuhkan bantuan, silakan hubungi tim IT kampus Anda atau lihat panduan pengguna.",
                style = MaterialTheme.typography.bodyMedium,
                textAlign = TextAlign.Center
            )
        }

        Button(
            onClick = onBackClick,
            modifier = Modifier.align(Alignment.CenterHorizontally)
        ) {
            Text(text = "Kembali ke Menu Utama")
        }
    }
}

@Composable
fun JadwalKuliahScreen(onBackClick: () -> Unit) {
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Text(
            text = "Jadwal Kuliah",
            style = MaterialTheme.typography.headlineMedium,
            fontWeight = FontWeight.Bold,
            modifier = Modifier.padding(bottom = 16.dp)
        )

        LazyColumn(verticalArrangement = Arrangement.spacedBy(8.dp)) {
            items(jadwalList) { jadwal ->
                Card(
                    shape = RoundedCornerShape(12.dp),
                    elevation = CardDefaults.cardElevation(4.dp),
                    modifier = Modifier.fillMaxWidth()
                ) {
                    Column(modifier = Modifier.padding(16.dp)) {
                        Text(
                            text = "${jadwal.no}. ${jadwal.mataKuliah}",
                            style = MaterialTheme.typography.bodyLarge,
                            fontWeight = FontWeight.Bold
                        )
                        Text(
                            text = "Kelas: ${jadwal.kelas}, SKS: ${jadwal.sks}",
                            style = MaterialTheme.typography.bodyMedium
                        )
                        Text(
                            text = "Dosen: ${jadwal.dosen}",
                            style = MaterialTheme.typography.bodyMedium
                        )
                        Text(
                            text = "Waktu: ${jadwal.waktu}, Ruang: ${jadwal.ruang}",
                            style = MaterialTheme.typography.bodyMedium
                        )
                    }
                }
            }
        }

        Button(
            onClick = onBackClick,
            modifier = Modifier.align(Alignment.CenterHorizontally)
        ) {
            Text(text = "Kembali ke Menu Utama")
        }
    }
}

val jadwalList = listOf(
    JadwalKuliah(1, "INFO-3527", "Pembelajaran Mesin", "F5A1", 3, "Dr. MUJIONO, ST., MT.", "UBJ-BKS || R. Said Soekanto || SS-423", "Rabu, 10:45 - 13:15"),
    JadwalKuliah(2, "INFO-3528", "Interaksi Manusia dan Komputer", "F5A6", 3, "Dian Hartanti, S.Kom., MMSI", "UBJ-BKS || R. Said Soekanto || SS-204", "Senin, 10:45 - 13:15"),
    JadwalKuliah(3, "INFO-3529", "Pemrograman Perangkat Bergerak", "F5A2", 3, "Arif Rifai Dwiyanto, ST., MTI", "UBJ-BKS || R. Said Soekanto || SS-412", "Rabu, 13:30 - 15:15"),
    JadwalKuliah(4, "INFO-3530", "Kecerdasan Buatan", "F5A6", 3, "Dr. Tb. Ai Munandar, S.Kom., MT", "UBJ-BKS || R. Said Soekanto || SS-423", "Senin, 08:00 - 10:30"),
    JadwalKuliah(5, "INFO-3531", "Keamanan Siber", "F5A2", 3, "Asep Ramdhani Mahbub, S.Kom., M.Kom.", "UBJ-BKS || R. Said Soekanto || R.K923", "Rabu, 08:00 - 10:30"),
)

data class JadwalKuliah(
    val no: Int,
    val kode: String,
    val mataKuliah: String,
    val kelas: String,
    val sks: Int,
    val dosen: String,
    val ruang: String,
    val waktu: String
)

@Composable
fun Footer(version: String, copyright: String) {
    Column(
        modifier = Modifier.fillMaxWidth(),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(
            text = "Versi $version",
            style = MaterialTheme.typography.bodySmall,
            textAlign = TextAlign.Center
        )
        Text(
            text = copyright,
            style = MaterialTheme.typography.bodySmall,
            textAlign = TextAlign.Center
        )
    }
}

@Preview(showBackground = true)
@Composable
fun MainMenuScreenPreview() {
    SIAMobileTheme {
        MainMenuScreen(onMenuClick = {})
    }
}

@Preview(showBackground = true)
@Composable
fun AboutScreenPreview() {
    SIAMobileTheme {
        AboutScreen(onBackClick = {})
    }
}

@Preview(showBackground = true)
@Composable
fun SettingsScreenPreview() {
    SIAMobileTheme {
        SettingsScreen(onBackClick = {})
    }
}

@Preview(showBackground = true)
@Composable
fun HelpScreenPreview() {
    SIAMobileTheme {
        HelpScreen(onBackClick = {})
    }
}

@Preview(showBackground = true)
@Composable
fun JadwalKuliahScreenPreview() {
    SIAMobileTheme {
        JadwalKuliahScreen(onBackClick = {})
    }
}
